@@ -19,8 +19,15 @@ from brownie.exceptions import (
 )
 from brownie.typing import AccountsType, TransactionReceiptType
 
+from eth_account import Account
+from eth_account.datastructures import SignedTransaction
 from .types import Wei, Address
 
+from eth_utils.toolz import (
+    assoc,
+    assoc_in,
+    dissoc,
+)
 
 class _ContractBase:
 
@@ -398,7 +405,32 @@ class _ContractMethod:
 
         return self.decode_output(data)
 
-    async def transact(self, *args: Tuple) -> TransactionReceiptType:
+    def build_transaction(self, *args: Tuple) -> SignedTransaction:
+        args, tx = _get_tx(args)
+
+        if not tx["from"]:
+            raise AttributeError(
+                "Final argument must be a dict of transaction parameters that "
+                "includes a `from` field specifying the sender of the transaction"
+            )
+
+        if "chainId" not in tx:
+            # defaults to chainId = 1
+            tx.update({"chainId": 1})
+        if "gas" not in tx:
+            raise AttributeError("we need 'gas' parameter.")
+        if "gasPrice" not in tx:
+            raise AttributeError("we need 'gasPrice' parameter.")
+        if "nonce" not in tx:
+            raise AttributeError("we need 'nonce' parameter.")
+
+        tx.update({"to": self._address, "data": self.encode_input(*args)})
+
+        account = tx["from"]
+        signed_txn = account.sign_transaction(dissoc(tx, 'from'))
+        return signed_txn
+
+    async def transact(self, *args: Tuple) -> Any:
         """
         Broadcast a transaction that calls this contract method.
 
@@ -413,25 +445,8 @@ class _ContractMethod:
         TransactionReceipt
             Object representing the broadcasted transaction.
         """
-
-        args, tx = _get_tx(args)
-        if not tx["from"]:
-            raise AttributeError(
-                "Final argument must be a dict of transaction parameters that "
-                "includes a `from` field specifying the sender of the transaction"
-            )
-
-        return tx["from"].transfer(
-            self._address,
-            tx["value"],
-            gas_limit=tx["gas"],
-            gas_buffer=tx["gas_buffer"],
-            gas_price=tx["gasPrice"],
-            nonce=tx["nonce"],
-            required_confs=tx["required_confs"],
-            data=self.encode_input(*args),
-            allow_revert=tx["allow_revert"],
-        )
+        signed_txn = self.build_transaction(*args)
+        return await self.web3.send_raw_transaction(signed_txn.rawTransaction)
 
     def decode_input(self, hexstr: str) -> List:
         """
@@ -543,12 +558,13 @@ class ContractTx(_ContractMethod):
 
         Returns
         -------
-        TransactionReceipt
+        An Awaitable Object
             Object representing the broadcasted transaction.
         """
-
         return self.transact(*args)
 
+    def build(self, *args: Tuple) -> SignedTransaction:
+        return self.build_transaction(*arg)
 
 class ContractCall(_ContractMethod):
 
@@ -589,7 +605,6 @@ def _get_tx(args: Tuple) -> Tuple:
         "from": None,
         "value": 0,
         "gas": None,
-        "gas_buffer": None,
         "gasPrice": None,
         "nonce": None,
     }
